summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--core/hdd/inc/wlan_hdd_assoc.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/core/hdd/inc/wlan_hdd_assoc.h b/core/hdd/inc/wlan_hdd_assoc.h
index ffa475016095..646bffee4dd0 100644
--- a/core/hdd/inc/wlan_hdd_assoc.h
+++ b/core/hdd/inc/wlan_hdd_assoc.h
@@ -84,14 +84,14 @@ typedef enum {
} eConnectionState;
/**
* typedef ePeerStatus - Peer status
* @ePeerConnected: peer connected
* @ePeerDisconnected: peer disconnected
*/
-typedef enum {
+enum peer_status {
ePeerConnected = 1,
ePeerDisconnected
-} ePeerStatus;
+};
/**
* struct hdd_conn_flag - connection flags
@@ -212,7 +212,6 @@ typedef struct hdd_adapter_s hdd_adapter_t;
typedef struct hdd_context_s hdd_context_t;
typedef struct hdd_station_ctx hdd_station_ctx_t;
typedef struct hdd_ap_ctx_s hdd_ap_ctx_t;
-typedef struct hdd_mon_ctx_s hdd_mon_ctx_t;
/**
* hdd_is_connecting() - Function to check connection progress
@@ -84,14 +84,14 @@ typedef enum {
} eConnectionState;
/**
- * typedef ePeerStatus - Peer status
+ * enum peer_status - Peer status
* @ePeerConnected: peer connected
* @ePeerDisconnected: peer disconnected